Module: OpenCL::CommandQueue::OpenCL11
- Included in:
- OpenCL::CommandQueue
- Defined in:
- lib/opencl_ruby_ffi/CommandQueue.rb
Instance Method Summary collapse
-
#enqueue_copy_buffer_rect(src_buffer, dst_buffer, region, options = {}) ⇒ Object
Enqueues a command to copy a rectangular region into a Buffer object from another Buffer object using the CommandQueue.
-
#enqueue_read_buffer_rect(buffer, ptr, region, options = {}) ⇒ Object
Enqueues a command to read from a rectangular region from a Buffer object to host memory using the CommandQueue.
-
#enqueue_write_buffer_rect(buffer, ptr, region, options = {}) ⇒ Object
Enqueues a command to write to a rectangular region in a Buffer object from host memory using the CommandQueue.
Instance Method Details
#enqueue_copy_buffer_rect(src_buffer, dst_buffer, region, options = {}) ⇒ Object
Enqueues a command to copy a rectangular region into a Buffer object from another Buffer object using the CommandQueue
Attributes
src_buffer- the Buffer to be read fromdst_buffer- the Buffer to be written toregion- the region to write in the Bufferoptions- a hash containing named options
Options
:event_wait_list- if provided, a list of Event to wait upon before executing the command:src_origin- if provided indicates the origin inside the src Buffer of the area to copy, else [0, 0, 0]:dst_origin- if provided indicates the origin inside the dst Buffer of the area to write to, else [0, 0, 0]:src_row_pitch- if provided indicates the row pitch inside the src Buffer, else 0:src_slice_pitch- if provided indicates the slice pitch inside the src Buffer, else 0:dst_row_pitch- if provided indicates the row pitch inside the dst Buffer, else 0:dst_slice_pitch- if provided indicates the slice pitch inside the dst Buffer area, else 0
Returns
the Event associated with the command
1579 1580 1581 |
# File 'lib/opencl_ruby_ffi/CommandQueue.rb', line 1579 def enqueue_copy_buffer_rect( src_buffer, dst_buffer, region, = {} ) return OpenCL.enqueue_copy_buffer_rect( self, src_buffer, dst_buffer, region, ) end |
#enqueue_read_buffer_rect(buffer, ptr, region, options = {}) ⇒ Object
Enqueues a command to read from a rectangular region from a Buffer object to host memory using the CommandQueue
Attributes
buffer- the Buffer to be read fromptr- the Pointer (or convertible to Pointer using to_ptr) to the memory area to useregion- the region in the Buffer to copyoptions- a hash containing named options
Options
:event_wait_list- if provided, a list of Event to wait upon before executing the command:blocking_read- if provided indicates if the command blocks until the region is read:blocking- if provided indicates if the command blocks until the region is read:buffer_origin- if provided indicates the origin inside the buffer of the area to copy, else [0, 0, 0]:host_origin- if provided indicates the origin inside the target host area, else [0, 0, 0]:buffer_row_pitch- if provided indicates the row pitch inside the buffer, else 0:buffer_slice_pitch- if provided indicates the slice pitch inside the buffer, else 0:host_row_pitch- if provided indicates the row pitch inside the host area, else 0:host_slice_pitch- if provided indicates the slice pitch inside the host area, else 0
Returns
the Event associated with the command
1525 1526 1527 |
# File 'lib/opencl_ruby_ffi/CommandQueue.rb', line 1525 def enqueue_read_buffer_rect( buffer, ptr, region, = {} ) return OpenCL.enqueue_read_buffer_rect( self, buffer, ptr, region, ) end |
#enqueue_write_buffer_rect(buffer, ptr, region, options = {}) ⇒ Object
Enqueues a command to write to a rectangular region in a Buffer object from host memory using the CommandQueue
Attributes
buffer- the Buffer to be written toptr- the Pointer (or convertible to Pointer using to_ptr) to the memory area to useregion- the region to write in the Bufferoptions- a hash containing named options
Options
:event_wait_list- if provided, a list of Event to wait upon before executing the command:blocking_write- if provided indicates if the command blocks until the region is written:blocking- if provided indicates if the command blocks until the region is written:buffer_origin- if provided indicates the origin inside the buffer of the area to copy, else [0, 0, 0]:host_origin- if provided indicates the origin inside the target host area, else [0, 0, 0]:buffer_row_pitch- if provided indicates the row pitch inside the buffer, else 0:buffer_slice_pitch- if provided indicates the slice pitch inside the buffer, else 0:host_row_pitch- if provided indicates the row pitch inside the host area, else 0:host_slice_pitch- if provided indicates the slice pitch inside the host area, else 0
Returns
the Event associated with the command
1553 1554 1555 |
# File 'lib/opencl_ruby_ffi/CommandQueue.rb', line 1553 def enqueue_write_buffer_rect( buffer, ptr, region, = {} ) return OpenCL.enqueue_write_buffer_rect( self, buffer, ptr, region, ) end |