Method: OpenCL::CommandQueue#enqueue_write_buffer
- Defined in:
- lib/opencl_ruby_ffi/CommandQueue.rb
#enqueue_write_buffer(buffer, ptr, options = {}) ⇒ Object
Enqueues a command to write to a Buffer object from host memory using the CommandQueue
Attributes
-
buffer- the Buffer to be written to -
ptr- the Pointer (or convertible to Pointer using to_ptr) to the memory area to use -
options- a hash containing named options
Options
-
:event_wait_list- if provided, a list of Event to wait upon before executing the command -
:blocking_write- if provided indicates if the command blocks until the region is written. -
:blocking- if provided indicates if the command blocks until the region is written -
:offset- if provided indicates the offset inside the Buffer of the area to read from, else 0 -
:size- if provided indicates the size of data to copy, else the maximum data is copied
Returns
the Event associated with the command
1152 1153 1154 |
# File 'lib/opencl_ruby_ffi/CommandQueue.rb', line 1152 def enqueue_write_buffer( buffer, ptr, = {} ) return OpenCL.enqueue_write_buffer( self, buffer, ptr, ) end |